pub struct CandyMachine {
pub authority: Pubkey,
pub wallet: Pubkey,
pub token_mint: Option<Pubkey>,
pub items_redeemed: u64,
pub data: CandyMachineData,
}Expand description
Candy machine state and config data.
Fields
wallet: Pubkeytoken_mint: Option<Pubkey>items_redeemed: u64data: CandyMachineDataTrait Implementations
Sourceimpl AccountDeserialize for CandyMachine
impl AccountDeserialize for CandyMachine
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for CandyMachine
impl AccountSerialize for CandyMachine
Sourceimpl BorshDeserialize for CandyMachine
impl BorshDeserialize for CandyMachine
Sourceimpl BorshSerialize for CandyMachine
impl BorshSerialize for CandyMachine
Sourceimpl Clone for CandyMachine
impl Clone for CandyMachine
Sourcefn clone(&self) -> CandyMachine
fn clone(&self) -> CandyMachine
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for CandyMachine
impl Default for CandyMachine
Sourcefn default() -> CandyMachine
fn default() -> CandyMachine
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for CandyMachine
impl Discriminator for CandyMachine
fn discriminator() -> [u8; 8]