pub struct CollectionPDA {
pub mint: Pubkey,
pub candy_machine: Pubkey,
}Expand description
Collection PDA account
Fields
mint: Pubkeycandy_machine: PubkeyTrait Implementations
Sourceimpl AccountDeserialize for CollectionPDA
impl AccountDeserialize for CollectionPDA
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for CollectionPDA
impl AccountSerialize for CollectionPDA
Sourceimpl BorshDeserialize for CollectionPDAwhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for CollectionPDAwhere
Pubkey: BorshDeserialize,
Sourceimpl BorshSerialize for CollectionPDAwhere
Pubkey: BorshSerialize,
impl BorshSerialize for CollectionPDAwhere
Pubkey: BorshSerialize,
Sourceimpl Clone for CollectionPDA
impl Clone for CollectionPDA
Sourcefn clone(&self) -> CollectionPDA
fn clone(&self) -> CollectionPDA
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CollectionPDA
impl Debug for CollectionPDA
Sourceimpl Default for CollectionPDA
impl Default for CollectionPDA
Sourcefn default() -> CollectionPDA
fn default() -> CollectionPDA
Returns the “default value” for a type. Read more
Sourceimpl Discriminator for CollectionPDA
impl Discriminator for CollectionPDA
fn discriminator() -> [u8; 8]