Modules
- accounts
- An Anchor generated module, providing a set of structs
mirroring the structs deriving
Accounts, where each field is aPubkey. This is useful for specifying accounts for a client. - candy_
machine - instruction
- An Anchor generated module containing the program’s set of
instructions, where each method handler in the
#[program]mod is associated with a struct defining the input arguments to the method. These should be used directly, when one wants to serialize Anchor instruction data, for example, when speciying instructions on a client. - program
- Module representing the program.
- utils
Structs
- AddConfig
Lines - Add multiple config lines to the candy machine.
- Candy
Machine - Candy machine state and config data.
- Candy
Machine Data - Candy machine settings data.
- CollectionPDA
- Collection PDA account
- Config
Line - Creator
- EndSettings
- Gatekeeper
Config - Configurations options for the gatekeeper.
- Hidden
Settings - Hidden Settings for large mints used with offline data.
- Initialize
Candy Machine - Create a new candy machine.
- MintNFT
- Mint a new NFT pseudo-randomly from the config array.
- Remove
Collection - Set the collection PDA for the candy machine
- SetCollection
- Set the collection PDA for the candy machine
- SetCollection
During Mint - Sets and verifies the collection during a candy machine mint
- Update
Candy Machine - Update the candy machine state.
- Whitelist
Mint Settings - Withdraw
Funds - Withdraw SOL from candy machine account.
Enums
Constants
- CONFIG_
ARRAY_ START - CONFIG_
LINE_ SIZE - Individual config line for storing NFT data pre-mint.
Statics
- ID
- The static program ID
Functions
- check_
id - Confirms that a given pubkey is equivalent to the program ID
- entry
- The Anchor codegen exposes a programming model where a user defines
a set of methods inside of a
#[program]module in a way similar to writing RPC request handlers. The macro then generates a bunch of code wrapping these user defined methods into something that can be executed on Solana. - entrypoint⚠
- Safety
- get_
config_ count - get_
config_ line - get_
good_ index - id
- Returns the program ID